<?php
/*
Plugin Name: WooCommerce Correios BR
Plugin URI: http://www.vibemidia.com/woocommerce-correios-sedex
Description: Calculo de frete dos Correios para WooCommerce. Siga a <a href="http://www.vibemidia.com/woocommerce-correios-sedex">documentação</a> para configurar. <strong>Adquira o plugin <a href="http://woocommerce.com.br/loja/woocommerce-moip-transparente/" target="_new">MoIP Transparente</a> para pagamento sem sair da página, <a href="http://woocommerce.com.br/plugin/pagamento-digital-plugin-para-woocommerce/" target="_new">Pagamento Digital</a>, <a href="http://woocommerce.com.br/plugin/moip-plugin-woocommerce/" target="_new">MoIP</a> e <a href="http://woocommerce.com.br/plugin/pagseguro-plugin-woocommerce//" target="_new">PagSeguro</a></strong>.
Version: 2.5.0
Author: John-Henrique
Author URI: http://johnhenrique.com
Text domain: WC-Correios-BR

Copyright: © 2009-2013 WooThemes.
License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

/**
 * Required functions
if ( ! function_exists( 'woothemes_queue_update' ) )
	require_once( 'woo-includes/woo-functions.php' );

 */
/**
 * Plugin updates
woothemes_queue_update( plugin_basename( __FILE__ ), '3af23dff540690a065e5cf30b930d483', '18674' );

 */
add_action('plugins_loaded', 'woocommerce_correios_init', 0);

function woocommerce_correios_init() {

    if (!class_exists('WC_Shipping_Method')) return;

    /**
     * Shipping method class
     * */
    class Correios extends WC_Shipping_Method {

        //var $url = 'http://ws.correios.com.br/calculador/CalcPrecoPrazo.aspx';
        //var $url = 'http://ws.correios.com.br/calculador/CalcPrecoPrazo.asmx/CalcPreco';
        var $url = 'http://ws.correios.com.br/calculador/CalcPrecoPrazo.asmx/CalcPrecoPrazo';

        function __construct() {
            global $woocommerce;

            $this->id = 'correios';
            $this->method_title = __('Correios', 'WC-Correios-BR');
            $this->plugin_version = '2.5.0';

            // Load the form fields.
            $this->init_form_fields();

            // Load the settings.
            $this->init_settings();

            $this->enabled 					= $this->settings['enabled'];
            $this->title 					= $this->settings['title'];
            $this->availability 			= 'specific';
            $this->origin_country 			= $woocommerce->countries->get_base_country();
            $this->origin_post 				= $this->cep( $this->settings['origin'] );
            $this->countries 				= array( "BR" );
            $this->selected_shipping_type 	= (is_array(get_option("woocommerce_correios_shipping_type", array()))) ? get_option("woocommerce_correios_shipping_type", array()) : array();
            $this->weight_unit 				= (get_option("woocommerce_weight_unit") == "kg") ? "KGS" : "LBS";
            $this->multiple_rates 			= true;
            $this->rates 					= array();

            $this->nCdEmpresa 				= $this->settings['nCdEmpresa'];
            $this->sDsSenha 				= $this->settings['sDsSenha'];
            
            $this->dias_adicionais			= $this->settings['dias_adicionais'];

			$this->debug					= $this->settings['debug'];

            // When a method has more than one cost/choice it will be in this array of titles/costs
            $this->shipping_type = array(
                'domestic' => array(
                    'PAC' 			=> new Correios_Pac(),
                    'SEDEX' 		=> new Correios_Sedex(),
                    'SEDEX10' 		=> new Correios_Sedex10(),
                    'ESEDEX' 		=> new Correios_Esedex(),
                    'SEDEXHOJE'		=> new Correios_Sedex_Hoje(),
                    'SEDEXACOBRAR'	=> new Correios_Sedex_Cobrar(),
                ),
                'international' => array(
                	/**
                	 * Correios no have international delivery webservice
                	 */
                )
            );


			// Logs
			if ($this->debug=='yes') $this->log = new WC_Logger();


			//$this->check();



            add_action('woocommerce_update_options_shipping_methods', array(&$this, 'process_admin_options'));
            add_action('woocommerce_update_options_shipping_correios', array(&$this, 'process_admin_options'));
            add_action('admin_notices', array(&$this, 'check_informations'));
        }

        /**
         * Initialise Gateway Settings Form Fields
         */
        function init_form_fields() {
            global $woocommerce;

            $this->form_fields = array(
                'enabled' => array(
                    'title' => __('Enable/Disable', 'WC-Correios-BR'),
                    'type' => 'checkbox',
                    'label' => __('Enable Correios', 'WC-Correios-BR'),
                    'default' => 'yes'
                ),
                'title' => array(
                    'title' => __('Method Title', 'WC-Correios-BR'),
                    'type' => 'text',
                    'description' => __('This controls the title which the user sees during checkout.', 'WC-Correios-BR'),
                    'default' => __('Correios', 'WC-Correios-BR')
                ),
                'origin' => array(
                    'title' => __('Origin Zip', 'WC-Correios-BR'),
                    'type' => 'text',
                    'description' => __('Enter your origin zip code.', 'WC-Correios-BR'),
                    'default' => ''
                ),

                'nCdEmpresa' => array(
                    'title' => __('Business', 'WC-Correios-BR'),
                    'type' => 'text',
                    'description' => __('Enter your contract code to E-SEDEX.', 'WC-Correios-BR'),
                    'default' => ''
                ),
                'sDsSenha' => array(
                    'title' => __('Password', 'WC-Correios-BR'),
                    'type' => 'text',
                    'description' => __('Enter your password to E-SEDEX service.', 'WC-Correios-BR'),
                    'default' => ''
                ),
                'dias_adicionais' => array(
                    'title' => __('Additional days', 'WC-Correios-BR'),
                    'type' => 'text',
                    'description' => __('If you need, you can add this field the amount of extra days should be added to the delivery.', 'WC-Correios-BR'),
                    'default' => 0
                )

                /**
                 * Yet can't choose international
                 *
                 * Correios no show documentation of
                 * international delivery
                 */
                ,
                'debug' => array(
                    'title' => __('Enable/Disable', 'WC-Correios-BR'),
                    'type' => 'checkbox',
                    'label' => __('Debug mode', 'WC-Correios-BR'),
                    'default' => 'yes'
                ),
            );
        }


        /**
         * Verify actual currency
         *
         * @return bool
         */
        protected function check_currency(){
			if ( in_array( get_option( 'woocommerce_currency' ), array( 'BRL' ) ) ):
			    if ($this->debug=='yes') $this->log->add( $this->id, __( "Check currency --> is correct", 'WC-Correios-BR' ) );
				return true;
			else:
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check currency --> is: %s", 'WC-Correios-BR' ), get_option( 'woocommerce_currency' ) ) );
				return false;
			endif;
        }

        /**
         * Verify actual country
         *
         * @return bool
         */
        protected function check_country(){
			if ( in_array( $this->origin_country, array( 'BR' ) ) ):
				if ($this->debug=='yes') $this->log->add( $this->id, __( "Check country --> is correct", 'WC-Correios-BR' ) );
				return true;
			else:
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check country --> is: %s", 'WC-Correios-BR' ), $this->origin_country ) );
				return false;
			endif;
        }

        /**
         * Verify actual origin post
         *
         * @return bool
         */
        protected function check_origin_post(){
			if( !empty( $this->origin_post ) ):
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check origin post --> is: %s", 'WC-Correios-BR' ), $this->origin_post ) );
				return true;
			else:
				if ($this->debug=='yes') $this->log->add( $this->id, __( "Check origin post --> was not informed", 'WC-Correios-BR' ) );
				return false;
			endif;
        }

        /**
         * Verify actual origin post format
         * Allowed this formats
         * 		78300000
         * 		78300-000
         *
         * @return bool
         */
        protected function check_post_format(){
            $zipcode = strlen( $this->origin_post );
            if( $zipcode > 7 && $zipcode < 10 ):
            	if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check postcode format --> have %s digits and is: %s", 'WC-Correios-BR' ), $zipcode, $this->origin_post ) );
				return true;
			else:
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check postcode format --> have format unknown with %s digits", 'WC-Correios-BR' ), $zipcode ) );
				return false;
			endif;
        }

        /**
         * Verify empresa info
         *
         * @return bool
         */
        protected function check_empresa(){
			if( !empty( $this->nCdEmpresa ) && empty( $this->sDsSenha ) ):
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check empresa --> is %s but senha was not informed", 'WC-Correios-BR' ), $this->nCdEmpresa ) );
				return false;
			else:
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check empresa --> is %s", 'WC-Correios-BR' ), $this->nCdEmpresa ) );
				return true;
			endif;
        }

        /**
         * Verify senha info
         *
         * @return bool
         */
        protected function check_senha(){
			if( !empty( $this->sDsSenha ) && empty( $this->nCdEmpresa ) ):
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check senha --> is %s but empresa was not informed", 'WC-Correios-BR' ), $this->sDsSenha ) );
				return false;
			else:
				if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Check senha --> is %s", 'WC-Correios-BR' ), $this->sDsSenha ) );
				return true;
			endif;
        }

        /**
         * Call all checks
         * Case any questions are true disable this plugin
         *
         */
        protected function check(){
        	if( !$this->check_currency() or !$this->check_country() or !$this->check_origin_post() or !$this->check_post_format() or !$this->check_empresa() or !$this->check_senha() ):
        		if ($this->debug=='yes') $this->log->add( $this->id, __( "Any error is happened, plugin was desabled", 'WC-Correios-BR' ) );
        		$this->enabled = false;
    		endif;
        }


        /**
         * Verify informations is fill
         *
         */
        public function check_informations() {

            if( !$this->check_currency() ):
                echo '<div class="error"><p>' . sprintf(__('Correios is enabled, but the <a href="%s">currency</a> is not BRL; Correios currently support only BRL.', 'WC-Correios-BR'), admin_url('admin.php?page=woocommerce&tab=general')) . '</p></div>';
            endif;

            if( !$this->check_country() ):
                echo '<div class="error"><p>' . sprintf(__('Correios is enabled, but the <a href="%s">base country/region</a> is not Brazil.', 'WC-Correios-BR'), admin_url('admin.php?page=woocommerce&tab=general')) . '</p></div>';
            endif;

            if( !$this->check_origin_post() ):
                echo '<div class="error"><p>' . sprintf(__('Correios is enabled, but the <a href="%s">origin zip code</a> is not available.', 'WC-Correios-BR'), admin_url('admin.php?page=woocommerce&tab=shipping#shipping-correios')) . '</p></div>';
            endif;

            if( !$this->check_post_format() ):
                echo '<div class="error"><p>'. sprintf(__('The <a href="%s">Zip code entered is invalid</a>. In Brazil, the postal code must follow the format 78300000 (8 digits).', 'WC-Correios-BR'), admin_url('admin.php?page=woocommerce&tab=shipping#shipping-correios')) . '</p></div>';
            endif;

            if( !$this->check_empresa() ){
            	echo '<div class="error"><p>'. sprintf(__('The company code is empty', 'WC-Correios-BR'), admin_url('admin.php?page=woocommerce&tab=shipping#shipping-correios')) . '</p></div>';
            }

            if( !$this->check_senha() ){
            	echo '<div class="error"><p>'. sprintf(__('The password is empty', 'WC-Correios-BR'), admin_url('admin.php?page=woocommerce&tab=shipping#shipping-correios')) . '</p></div>';
            }
            
            // display a message when this method no have a return.
            echo "&nbsp;";
        }




        function calculate_shipping() {
            global $woocommerce;
            
            /**
             * To call headers of log only once 
             */
            if($this->debug=='yes') $this->log->add(  $this->id, 'WooCommerce version: '. WOOCOMMERCE_VERSION );
            if ($this->debug=='yes') $this->log->add( $this->id, __( "WC Correios version: ", 'WC-Correios-BR' ) . $this->plugin_version );
            $this->check();
            
            $customer = $woocommerce->customer;
            $weight = 0;

            $this->shipping_total = 0;
            $this->shipping_tax = 0;

            if ($this->debug=='yes') $this->log->add( $this->id, __( "calculate_shipping was initialized", 'WC-Correios-BR' ) );

            if (sizeof($woocommerce->cart->get_cart()) > 0 && ($customer->get_shipping_state()) || $customer->get_shipping_postcode()) {

                foreach ($woocommerce->cart->get_cart() as $item_id => $values) {

                    $_product = $values['data'];

                    if ($_product->exists() && $values['quantity'] > 0) {

                        if (!$_product->is_virtual()) {

                            $weight += $_product->get_weight() * $values['quantity'];
                        }
                    }
                }

                $data['weight'] = (empty($weight))? '0.300':$weight;
               
                if ( $data['weight'] ) {

                	if ($this->debug=='yes') $this->log->add( $this->id, __( "weight is defined", 'WC-Correios-BR' ) );

                    $this->get_shipping_response($data);
                }


            }
        }



        /**
         * Set shipping rates from cache or from Correios API
         * @global type $woocommerce
         * @param type $data
         */
        function get_shipping_response($data = false) {
            global $woocommerce;

            $label = "";
            $shipping_methods = array();

            $customer = $woocommerce->customer;
            $doi = ($this->origin_country == $customer->get_shipping_country()) ? 'domestic' : 'international';


            if ($this->debug=='yes') $this->log->add( $this->id, __( "get_shipping_response was initialized", 'WC-Correios-BR' ) );



            $cart_items = $woocommerce->cart->get_cart();
            foreach ($cart_items as $id => $cart_item) {
                $cart_temp[] = $id . $cart_item['quantity'];
            }


			foreach ($this->shipping_type[$doi] as $typename => $shipping_type){
                if (in_array($typename, $this->selected_shipping_type)) {
                    $shipping_data['Shipping_Type'] = $typename;

                    // methods selecteds
                    $shipping_methods[] = $shipping_type->id;
                    $shipping_titles[] = $shipping_type->title;
                }

            }


            if ($this->debug=='yes') $this->log->add( $this->id, __( "correios request in processing", 'WC-Correios-BR' ) );

    		$correioParams = array(
		        'nCdEmpresa' 			=> $this->nCdEmpresa, // optional
		        'sDsSenha' 				=> $this->sDsSenha, // optional
		        'nCdServico' 			=> implode( ',', $shipping_methods ), // string
		        'sCepOrigem' 			=> $this->cep( $this->origin_post ), // string Only numbers
		        'sCepDestino' 			=> $this->cep( $customer->get_shipping_postcode() ), // string
		        'nVlPeso' 				=> $data['weight'], // string 0.300 until 30.0
		        'nCdFormato' 			=> 1, // integer 1 box/package || 2 prism/roll
		        'nVlComprimento' 		=> '16',//16, // decimal
		        'nVlAltura' 			=> '16',//16, // decimal
		        'nVlLargura' 			=> '16',//16, // decimal
		        'nVlDiametro' 			=> 0, // decimal
		        'nVlValorDeclarado' 	=> $woocommerce->cart->cart_contents_total, // decimal, if use this, enter the product cost
		        'sCdAvisoRecebimento' 	=> 'N', // string N No || S Yes
		        'sCdMaoPropria' 		=> 'N', // string N No || S Yes
		        'StrRetorno' 			=> 'xml' //
	        );

	        if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "correios request data is %s", 'WC-Correios-BR' ), print_r( $correioParams, true ) ) );


            $correioResponse = $this->correios_query( $correioParams );


            if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "correios result is %s", 'WC-Correios-BR' ), gettype( $correioResponse ) ) );

            if ( isset( $correioResponse->cServico ) && !empty( $correioResponse->cServico ) ) {
	            for ( $i=0; $i <= count( $correioResponse->cServico ); $i++){

	            	// atalho
	            	$correioMethod = $correioResponse->cServico[ $i ];


					// Have errors?
	            	if( empty( $correioMethod->Erro ) && !empty( $correioMethod->Valor ) ){

		            	$whoIs = 1;


		            		// shipping time in days
		            		$prazo_entrega = $correioMethod->PrazoEntrega;
		            		

			            	if( 1 < $prazo_entrega ){
			            		$whoIs = 2;
			            	}

			            	
			            	/**
			            	 * Addtional days to sum
			            	 * If $this->dias_adicionais no have a integer or 
			            	 * the value is a string, 0 is defined.
			            	 */
			            	if( empty( $this->dias_adicionais ) || !ctype_digit( $this->dias_adicionais ) ){
			            		$this->dias_adicionais = 0;
			            	}else{
			            		$prazo_entrega = ( $prazo_entrega + $this->dias_adicionais );
			            	}
			            	
			            	
			            	
			            	if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Additional days %s", 'WC-Correios-BR' ), $this->dias_adicionais ) );
			            	if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Shipping in %s days", 'WC-Correios-BR' ), $correioMethod->PrazoEntrega ) );
			            	if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "Delivery in %s days", 'WC-Correios-BR' ), $prazo_entrega ) );
			            	
			            	
			            	
			            	/**
			            	 * Exists some methods of delivery but
			            	 * is very important show when business
			            	 * days will it take to delivery
			            	 *
			            	 * This was my 'hack' but might have
			            	 * a index to store this information
			            	 */
			            	$deliveryDays = ' ('. sprintf( _n( "Delivery in %s business day", "Delivery in %s business days", $whoIs, 'WC-Correios-BR' ), $prazo_entrega ) .')';


			            	/**
			            	 * A bug is adding twice
			            	 *
			            	 * This try prevent the bug
			            	 */
			            	if( !strstr( $shipping_titles[ $i ], $deliveryDays ) ){
			            		$label = $shipping_titles[ $i ] . $deliveryDays;
			            	}

		            	$shippingMethod = str_replace( ',','.', $correioMethod->Valor) + $this->get_fee($this->fee, $woocommerce->cart->cart_contents_total);

						$taxas =  array(
						    'id' => $this->title ." ". $label,
						    'label' => $label,
						    'cost' => $shippingMethod,
						    'taxes' => '',
						    'calc_tax' => 'per_item'
						);

						if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "shipping method processed info %s %s", 'WC-Correios-BR' ), $label, $shippingMethod ) );

						// new method
						$this->add_rate( $taxas );
	            	}
	            }
            }
        }






        /**
         * Consulta a API
         * Shipping result from the end point
         * @param type $data
         * @param type $cache
         * @return response
         */
        function correios_query( $data = false, $cache = false )
        {

        	if ($this->debug=='yes') $this->log->add( $this->id, __( "correios_query was initialized", 'WC-Correios-BR' ) );

        	$target = $this->api_fix( $this->url ."?". http_build_query( $this->correios_correct_keys( $data ) ) );

        	$http = new WP_Http();
        	$resposta = $http->request( $target );

        	if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "URL API: %s", 'WC-Correios-BR' ), $target ) );

        	// change return
        	if( is_wp_error( $resposta ) ) {

        		if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "correios_query error %s", 'WC-Correios-BR' ), print_r( $resposta, true ) ) );

        		
        		/**
        		 * Verifing if have connect with host
        		 */
        		if( strpos( $resposta->errors['http_request_failed'][0], 'Could not resolve host' ) ){
        			
        			return $resposta['body'] = "Não foi possível conectar-se com o host API dos Correios.";
        		}
        		
        		return false;
        	}

        	$xml_frete = simplexml_load_string( $resposta['body'] );


        	if ($this->debug=='yes') $this->log->add( $this->id, sprintf( __( "correios_query returned %s", 'WC-Correios-BR' ), print_r( $xml_frete , true) ) );



        	return $xml_frete->Servicos;
        }



        /**
         * Fix URL API
         *
         * @param unknown_type $url
         * @return unknown
         */
        function api_fix( $url = '' ){
        	return str_replace( 'amp;', '', $url );
        }


        /**
         * Any values need a minimum value
         * this function replace this values when
         * necessary
         *
         * @param Array $data
         */
        function correios_correct_keys( $data )
        {

        	// minimum size 16
        	if( $data['nVlComprimento'] < 16 ){
        		$data['nVlComprimento'] = 16;
        	}

        	// minimum size 16
        	if( $data['nVlAltura'] < 16 ){
        		$data['nVlAltura'] = 16;
        	}

        	// minimum size 16
        	if( $data['nVlLargura'] < 16 ){
        		$data['nVlLargura'] = 16;
        	}


        	// format value
        	if( strstr( $data['nVlValorDeclarado'], ',' ) == false ){
        		$data['nVlValorDeclarado'] = trim( str_replace( '.', ',', $data['nVlValorDeclarado'] ) );
        	}



        	return $data;
        }



        /**
         * CEP
         * only numbers are accepted
         *
         * @param String $string
         * @return String
         */
        protected function cep( $string = null ){
        	return filter_var( $string, FILTER_SANITIZE_NUMBER_INT );
        }




        /**
         * Admin Panel Options
         * - Options for bits like 'title' and availability on a country-by-country basis
         *
         * @since 1.0.0
         */
        public function admin_options() {
            ?>
            <h3><?php _e('Correios', 'WC-Correios-BR'); ?></h3>
            <p><?php _e('Correios calculates shipping price base on Correios standard. The input fields Business and Password are used only on E-SEDEX.', 'WC-Correios-BR'); ?></p>
            <?php $this->check_informations(); ?>
            <table class="form-table">
                <?php
                // Generate the HTML For the settings form.
                $this->generate_settings_html();
                ?>
                <tr valign="top">
                    <th scope="row" class="titledesc"><?php _e('Shipping methods', 'WC-Correios-BR') ?></th>
                    <td class="forminp">
                        <?php
                        $shipping_types = array_merge($this->shipping_type['domestic'], $this->shipping_type['international']);
                        foreach ($shipping_types as $key => $shipping_type):
                            ?>
                            <input type="checkbox" name="woocommerce_correios_shipping_type[]" value="<?php echo $key ?>" id="<?php echo $key ?>" <?php
				                if (in_array($key, $this->selected_shipping_type)) {
				                    echo 'checked="checked"';
				                }
                            ?> /><label for="<?php echo $key; ?>"><?php echo $shipping_type->title ?></label>
                            </br>
                        <?php endforeach; ?>
                    </td>
                </tr>

            </table><!--/.form-table-->
            <?php
        }



        function process_admin_options() {
            parent::process_admin_options();

            if (isset($_POST['woocommerce_correios_shipping_type']))
                $selected_shipping_type = $_POST['woocommerce_correios_shipping_type'];
            else
                $selected_shipping_type = array();
            update_option('woocommerce_correios_shipping_type', $selected_shipping_type);
        }



    }

    class CorreiosError {

        var $number;
        var $description;
        var $response;

    }


    class Correios_Pac extends Correios {

        function __construct($shipping = false) {
            $this->id = 41106;
            $this->title = __('PAC', 'WC-Correios-BR');
            $this->shipping_total = $shipping;
        }

    }

    class Correios_Sedex extends correios {

        function __construct($shipping = false) {
            $this->id = 40010;
            $this->title = __('SEDEX', 'WC-Correios-BR');
            $this->shipping_total = $shipping;
        }

    }

    class Correios_Sedex10 extends correios {

        function __construct($shipping = false) {
            $this->id = 40215;
            $this->title = __('SEDEX 10', 'WC-Correios-BR');
            $this->shipping_total = $shipping;
        }

    }

    class Correios_Sedex_Hoje extends correios {

        function __construct($shipping = false) {
            $this->id = 40290;
            $this->title = __('SEDEX hoje', 'WC-Correios-BR');
            $this->shipping_total = $shipping;
        }

    }

    class Correios_Sedex_Cobrar extends correios {

        function __construct($shipping = false) {
            $this->id = 40045;
            $this->title = __('SEDEX a cobrar', 'WC-Correios-BR');
            $this->shipping_total = $shipping;
        }

    }

    class Correios_Esedex extends correios {

        function __construct($shipping = false) {
            $this->id = 81019;
            $this->title = __('E-SEDEX', 'WC-Correios-BR');
            $this->shipping_total = $shipping;
        }

    }

	load_plugin_textdomain('WC-Correios-BR', false, basename( dirname( __FILE__ ) ) . '/languages' );

    function add_correios_method($methods) {
        $methods[] = 'Correios';
        return $methods;
    }

    add_filter('woocommerce_shipping_methods', 'add_correios_method');
}